@@ -1,5 +1,12 @@
 context("get_resource_url")
 
+# start_capturing(path = './tests/testthat')
+# dkanr_setup(url = "https://www.statistics.digitalresources.jisc.ac.uk/")
+# metadata <- retrieve_node(nid = 2400, as = 'list')
+# get_resource_url(metadata)
+# stop_capturing()
+
+
 # Set up
 dkanr_setup(url = "https://datacatalog.worldbank.org")
 load("metadata.rda")
@@ -25,4 +32,14 @@ test_that("field_resource URLs are correctly extracted", {
   )
   expect_true(class(get_resource_url(metadata_rs_dkan)) == "character")
   expect_true(is.atomic(class(get_resource_url(metadata_rs_dkan))))
+
+})
+
+httptest::with_mock_api({
+  dkanr_setup(url = "https://www.statistics.digitalresources.jisc.ac.uk/")
+  metadata <- retrieve_node(nid = 2400, as = 'list')
+  expect_equal(
+    get_resource_url(metadata),
+    "http://s3-eu-west-1.amazonaws.com/statistics.digitalresources.jisc.ac.uk/dkan/files/AGE_LANENG/AGE_LANENG_Database-FriendlyFormat.zip"
+  )
 })
